import { KeyObject } from 'crypto';
import react, { ReactNode } from 'react';
import { lat2tile, lon2tile } from '../../lib/geo';
import { CoordinateSystem } from './LiveMap';
import { geoPoint, TileKeyObject } from './types';

export interface MarkerProperties {
  coordinates: geoPoint;
  icon: ReactNode;
  keyObject?: TileKeyObject;
  zoom?: number;
}

export const Marker: react.FC<MarkerProperties> = (props: MarkerProperties) => {
  if (props.keyObject === undefined || props.zoom === undefined) return null;

  const x = lon2tile(props.coordinates.lon, props.keyObject.zoomLevel);
  const y = lat2tile(props.coordinates.lat, props.keyObject.zoomLevel);
  return (
    <g transform={`translate(${x}, ${y}) scale(${1 / props.zoom})`}>
      {props.icon}
    </g>
  );
};

export default Marker;
